==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/web.beans/src/org/netbeans/modules/web/beans/model/spi/WebBeansModelProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.web.beans.model.spi;

import java.util.Collection;
import java.util.List;

import javax.lang.model.element.AnnotationMirror;
import javax.lang.model.element.Element;
import javax.lang.model.element.ExecutableElement;
import javax.lang.model.element.TypeElement;
import javax.lang.model.element.VariableElement;
import javax.lang.model.type.DeclaredType;
import javax.lang.model.type.TypeMirror;

import org.netbeans.api.java.source.CompilationController;
import org.netbeans.modules.web.beans.api.model.BeanArchiveType;
import org.netbeans.modules.web.beans.api.model.CdiException;
import org.netbeans.modules.web.beans.api.model.InjectionPointDefinitionError;
import org.netbeans.modules.web.beans.api.model.DependencyInjectionResult;
import org.netbeans.modules.web.beans.api.model.InterceptorsResult;


/**
 * @author ads
 *
 */
public interface WebBeansModelProvider {

    DependencyInjectionResult lookupInjectables( VariableElement element , DeclaredType parentType);
    
    boolean isDynamicInjectionPoint( VariableElement element );
    
    boolean isInjectionPoint( VariableElement element ) throws InjectionPointDefinitionError;
    
    List<AnnotationMirror> getQualifiers( Element element , boolean all );

    List<Element> getNamedElements( );

    String getName( Element element);

    List<ExecutableElement> getObservers( VariableElement element,
            DeclaredType parentType);

    List<VariableElement> getEventInjectionPoints( ExecutableElement element,
            DeclaredType parentType);

    VariableElement getObserverParameter( ExecutableElement element);
    
    String getScope( Element element ) throws CdiException;

    CompilationController getCompilationController();

    TypeMirror resolveType( String fqn);

    boolean hasImplicitDefaultQualifier( Element element );

    Collection<TypeElement> getDecorators( TypeElement element );

    InterceptorsResult getInterceptors( Element element );

    Collection<AnnotationMirror> getInterceptorBindings( Element element );

    BeanArchiveType getBeanArchiveType();
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/web.beans/src/org/netbeans/modules/web/beans/model/spi/WebBeansModelProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.web.beans.model.spi;

import java.util.Collection;
import java.util.List;
import java.util.concurrent.atomic.AtomicBoolean;

import javax.lang.model.element.AnnotationMirror;
import javax.lang.model.element.Element;
import javax.lang.model.element.ExecutableElement;
import javax.lang.model.element.TypeElement;
import javax.lang.model.element.VariableElement;
import javax.lang.model.type.DeclaredType;
import javax.lang.model.type.TypeMirror;

import org.netbeans.api.java.source.CompilationController;
import org.netbeans.modules.web.beans.api.model.BeanArchiveType;
import org.netbeans.modules.web.beans.api.model.CdiException;
import org.netbeans.modules.web.beans.api.model.InjectionPointDefinitionError;
import org.netbeans.modules.web.beans.api.model.DependencyInjectionResult;
import org.netbeans.modules.web.beans.api.model.InterceptorsResult;


/**
 * @author ads
 *
 */
public interface WebBeansModelProvider {

    DependencyInjectionResult lookupInjectables( VariableElement element , DeclaredType parentType, AtomicBoolean cancel);
    
    boolean isDynamicInjectionPoint( VariableElement element );
    
    boolean isInjectionPoint( VariableElement element ) throws InjectionPointDefinitionError;
    
    List<AnnotationMirror> getQualifiers( Element element , boolean all );

    List<Element> getNamedElements(AtomicBoolean cancel);

    String getName( Element element);

    List<ExecutableElement> getObservers( VariableElement element,
            DeclaredType parentType);

    List<VariableElement> getEventInjectionPoints( ExecutableElement element,
            DeclaredType parentType);

    VariableElement getObserverParameter( ExecutableElement element);
    
    String getScope( Element element ) throws CdiException;

    CompilationController getCompilationController();

    TypeMirror resolveType( String fqn);

    boolean hasImplicitDefaultQualifier( Element element );

    Collection<TypeElement> getDecorators( TypeElement element );

    InterceptorsResult getInterceptors( Element element );

    Collection<AnnotationMirror> getInterceptorBindings( Element element );

    BeanArchiveType getBeanArchiveType();

    boolean isCdi11OrLater();
}
